# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load Prepared Data ####

# Grants
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)

# Budgets
budget.rda <- file.path(parent.dir, "Prepared Data", "Budgets.rda")
load(budget.rda)
head(budget)

# PCC and SBA Training Hours and Participants
training.rda <- file.path(parent.dir, "Prepared Data", 
                          "PCC and SBA Training Hours and Participants.rda")
load(training.rda)
head(training.lab)



# Table 3. PCC and SBA Training ####

# Training totals
training_totals <- training.lab[
  `Focus Area` != "Open Lab", lapply(.SD, sum), .SDcols = 3:4,
  keyby = Award_Num]

# Lookup hours and budgets
d <- budget[training_totals[grants[Grant_Type %in% c("PCC", "SBA")]]]

# Drop defunded
d <- d[Defunded == ""]

# Aggregate
sdc <- c("Participants", "Hours", "total")
# totals
cst <- d[, lapply(.SD, sum), by = list(Grant_Type, Case_Study), .SDcols = sdc]
abt <- d[, lapply(.SD, sum), by = list(
  Grant_Type, Case_Study = rep("All", nrow(d))), .SDcols = sdc]
# averages
csa <- d[, lapply(.SD, mean), by = list(Grant_Type, Case_Study), .SDcols = sdc]
aba <- d[, lapply(.SD, mean), by = list(
  Grant_Type, Case_Study = rep("All", nrow(d))), .SDcols = sdc]

# Bind totals
d <- rbind(cst, abt)[, s := "Total"]

# Calculate
d[, dollarper := total / Hours]

# Bind averages
d <- rbind.fill(d, rbind(csa, aba)[, s := "Average"])

# Millions
d$total <- d$total / 1e6

# Reshape
d <- as.data.table(melt(d, id.vars = c("Grant_Type", "Case_Study", "s")))

# Format
d <- d[!is.na(value)]
d[, row := factor(paste(s, variable), c(
  "Total Participants", "Average Participants", "Total Hours", "Average Hours",
  "Total total", "Average total", "Total dollarper"), c(
    "Total training participants", 
    "Average number of training participants per grantee", 
    "Total training hours", "Average number of training hours per grantee",
    "Total budget (millions)", 
    "Average budget (millions) per grantee",
    "Budget dollars per training hour"))]
d[grepl("Total budget", row), v := paste0("$", sprintf("%.0f", value))]
d[grepl("Average budget", row), v := paste0("$", sprintf("%.1f", value))]
d[grepl("dollar", row), v := paste0("$", sprintf("%.2f", value))]
d[is.na(v), v := formatC(value, 0, format = "f", big.mark = ",")]

# Table
train_budg <- tabular(
  Heading("Metric") * row ~ 
    Heading() * droplevels(Grant_Type) * Heading() * Case_Study * 
    Heading() * v * Heading() * identity, d)
(train_budg <- train_budg[, -c(2, 5)])

# Write
write.xlsx.tabular(train_budg, file.path(sec1, "Table 3.xlsx"))
