/*********************************************/
/*User import to point to the file containing*/
/*the IMPLAN employment estimate spreadsheets*/
/*********************************************/
%let FTE_Folder=C:\Documents and Settings\ASR User\My Documents\BTOP\Short-Term Economic Impacts Report\FTE Totals\;

/*Read in the conversion table from IMPLAN*/
proc import
datafile="&FTE_Folder.Convert_IMPLANemployment_to_FTE.xls"
out=Convert_IMPLANtoFTE
dbms=xls;
run;


/*Read in each of the IMPLAN employment outputs*/
proc import
datafile="&FTE_Folder.IMPLANoutput_Totalbudget.xls"
out=Total_Budget
dbms=xls;
run;

proc import
datafile="&FTE_Folder.IMPLANoutput_TotalFedBudget.xls"
out=TotalFed_Budget
dbms=xls;
run;

proc import
datafile="&FTE_Folder.IMPLANoutput_TotalSpend.xls"
out=Total_Spend
dbms=xls;
run;

proc import
datafile="&FTE_Folder.IMPLANoutput_FedBudget_PCCSBA.xls"
out=FedBudget_PCCSBA
dbms=xls;
run;

proc import
datafile="&FTE_Folder.IMPLANoutput_FedBudget_CCI.xls"
out=FedBudget_CCI
dbms=xls;
run;

proc import
datafile="&FTE_Folder.IMPLANoutput_TotalBudget_CCI.xls"
out=TotBudget_CCI
dbms=xls;
run;

proc import
datafile="&FTE_Folder.IMPLANoutput_TotalBudget_PCCSBA.xls"
out=TotBudget_PCCSBA
dbms=xls;
run;


/*Calculate FTE conversions from IMPLAN employment output for each scenario*/
proc sql;
create table FTE_TotalBudget as
select a.sector, a.description, a.total, a.total*b.FTE_per_Employment as FTE, 
a.direct, a.direct*b.FTE_per_Employment as FTE_Direct, a.indirect, a.indirect*b.FTE_per_Employment as FTE_Indirect,
a.induced, a.induced*b.FTE_per_Employment as FTE_Induced
from Total_Budget as a left join Convert_IMPLANtoFTE as b
on a.sector=b.IMPLAN_Sector_Code;
quit;

proc sql;
create table FTE_TotalSpend as
select a.sector, a.description, a.total, a.total*b.FTE_per_Employment as FTE,
a.direct, a.direct*b.FTE_per_Employment as FTE_Direct, a.indirect, a.indirect*b.FTE_per_Employment as FTE_Indirect,
a.induced, a.induced*b.FTE_per_Employment as FTE_Induced
from Total_Spend as a left join Convert_IMPLANtoFTE as b
on a.sector=b.IMPLAN_Sector_Code;
quit;

proc sql;
create table FTE_TotalFedBudget as
select a.sector, a.description, a.total, a.total*b.FTE_per_Employment as FTE,
a.direct, a.direct*b.FTE_per_Employment as FTE_Direct, a.indirect, a.indirect*b.FTE_per_Employment as FTE_Indirect,
a.induced, a.induced*b.FTE_per_Employment as FTE_Induced
from TotalFed_Budget as a left join Convert_IMPLANtoFTE as b
on a.sector=b.IMPLAN_Sector_Code;
quit;

proc sql;
create table FTE_FedBudget_PCCSBA as
select a.sector, a.description, a.total, a.total*b.FTE_per_Employment as FTE,
a.direct, a.direct*b.FTE_per_Employment as FTE_Direct, a.indirect, a.indirect*b.FTE_per_Employment as FTE_Indirect,
a.induced, a.induced*b.FTE_per_Employment as FTE_Induced
from FedBudget_PCCSBA as a left join Convert_IMPLANtoFTE as b
on a.sector=b.IMPLAN_Sector_Code;
quit;

proc sql;
create table FTE_FedBudget_CCI as
select a.sector, a.description, a.total, a.total*b.FTE_per_Employment as FTE,
a.direct, a.direct*b.FTE_per_Employment as FTE_Direct, a.indirect, a.indirect*b.FTE_per_Employment as FTE_Indirect,
a.induced, a.induced*b.FTE_per_Employment as FTE_Induced
from FedBudget_CCI as a left join Convert_IMPLANtoFTE as b
on a.sector=b.IMPLAN_Sector_Code;
quit;

proc sql;
create table FTE_TotBudget_CCI as
select a.sector, a.description, a.total, a.total*b.FTE_per_Employment as FTE,
a.direct, a.direct*b.FTE_per_Employment as FTE_Direct, a.indirect, a.indirect*b.FTE_per_Employment as FTE_Indirect,
a.induced, a.induced*b.FTE_per_Employment as FTE_Induced
from TotBudget_CCI as a left join Convert_IMPLANtoFTE as b
on a.sector=b.IMPLAN_Sector_Code;
quit;

proc sql;
create table FTE_TotBudget_PCCSBA as
select a.sector, a.description, a.total, a.total*b.FTE_per_Employment as FTE,
a.direct, a.direct*b.FTE_per_Employment as FTE_Direct, a.indirect, a.indirect*b.FTE_per_Employment as FTE_Indirect,
a.induced, a.induced*b.FTE_per_Employment as FTE_Induced
from TotBudget_PCCSBA as a left join Convert_IMPLANtoFTE as b
on a.sector=b.IMPLAN_Sector_Code;
quit;


%macro export(Table_Name);
proc export
data=&Table_Name
outfile="&FTE_Folder.&Table_Name..xlsx"
dbms=xlsx
replace;
run;
%mend export;

%export(FTE_TotalBudget);
%export(FTE_TotalSpend);
%export(FTE_TotalFedBudget);
%export(FTE_FedBudget_PCCSBA);
%export(FTE_FedBudget_CCI);
%export(FTE_TotBudget_CCI);
%export(FTE_TotBudget_PCCSBA);
