/****************************************************************************************
User defined inputs to locate input BTOP Expenditure Data set, the Datamap file and set 
the output folder where Expenditure Summary Tables will be saved.
****************************************************************************************/
%let BTOP_Expend=C:\Users\Ben\Desktop\Short-Term Economic Impacts Report\BTOP_Expenditures_2013_06_11.xls;
%let DataMap=C:\Users\Ben\Desktop\Short-Term Economic Impacts Report\DataMapping_final.xls;
%let IO_Directory=C:\Users\Ben\Desktop\Short-Term Economic Impacts Report\IMPLAN Input Tables; /*This must be the folder where the IO_Template file is stored and where you want expenditure tables output*/


/**************************************************************************
Import the BTOP_Expenditure Spreadsheet with expenditure data for all grants for all quarters
**************************************************************************/
proc import
out=BTOP_Expenditures
datafile="&BTOP_Expend"
dbms=xls replace;
run;

/************************************************************
Import the Data Mapping file in order to map PPR expenditure 
categories to IMPLAN Sectors and weight appropriately.
*************************************************************/
Proc import
out=DataMap_PCC_SBA
datafile="&Datamap"
dbms=xls 
replace;
sheet="PCC_SBA";
run;

Proc import
out=DataMap_CCI
datafile="&Datamap"
dbms=xls
replace;
sheet="CCI";
run;

/********************************************************************************
Create table 'base_dataset' that cleans up the formatting of the BTOP_Expenditure table
by reformatting the "Award_Number" variable and creating just two grant types: "PCC_SBA" and "INF"
********************************************************************************/
data base_dataset;
set BTOP_Expenditures;
award_number=compress(award_number,'-');
award_number=compress(award_number,'_');
if Project_Type="PCC" then
	Project_Type="PCC_SBA";
	else if Project_Type="SBA" then
	Project_Type="PCC_SBA";
	else if Project_Type="INF" then
	Project_Type="CCI";
run;

/*************************************************************************************/
/*Filter the data set to keep only the most recent quarter available for each grantee*/
/*************************************************************************************/
proc sort data=base_dataset out=input1;
by descending award_number descending year descending quarter;
run;
proc sort data=input1 out=MostRecent_Qtr nodupkey;
by Award_number;
run;

/****************************************************************************************************/
/*Break grants into three size classifications using their total budgets: 'High', 'Medium', or 'Low'*/
/****************************************************************************************************/
proc sql;
create table MostRecent_pcc_sba as
select *, case
when (matchfundplan_total_amt+fedfundplan_total_amt)>=10000000 then "High"
when (matchfundplan_total_amt+fedfundplan_total_amt)>=5000000 and (matchfundplan_total_amt+fedfundplan_total_amt) <10000000 then "Medium"
when (matchfundplan_total_amt+fedfundplan_total_amt)<5000000 then "Low"
else "error"
end as Size
from MostRecent_Qtr
where Project_type="PCC_SBA";
quit;

proc sql;
create table mostrecent_cci as 
select *, case
when (matchfundplan_total_amt+fedfundplan_total_amt)>=50000000 then "high"
when (matchfundplan_total_amt+fedfundplan_total_amt)>=15000000 and (matchfundplan_total_amt+fedfundplan_total_amt) <50000000 then "Medium"
when (matchfundplan_total_amt+fedfundplan_total_amt)<15000000 then "low"
else "error"
end as Size
from MostRecent_Qtr
where Project_type="CCI";
quit;

/*****************************************************************************************/
/*Macro to make Total Budget, Fed Budget, and Tot Spend tables mapped to IMPLAN 440 Codes*/
/*****************************************************************************************/
%macro BudgetTables(proj_type);
proc sql;
create table TotalBudget_&proj_type as
select Project_Type, 
sum(MatchFundPlan_ArchFee_Amt) + sum(FedFundPlan_ArchFee_Amt) as ArchFee_Amt format dollar18.,     
sum(MatchFundPlan_Benefits_Amt) + sum(FedFundPlan_Benefits_Amt) as Benefits_Amt format dollar18.,
sum(MatchFundPlan_Constructn_Amt) + sum(FedFundPlan_Constructn_Amt) as Constructn_Amt format dollar18.,
sum(MatchFundPlan_Contract_Amt) + sum(FedFundPlan_Contract_Amt) as Contract_Amt format dollar18., 
sum(MatchFundPlan_Demolitn_Amt) + sum(FedFundPlan_Demolitn_Amt) as Demolitn_Amt format dollar18., 
sum(MatchFundPlan_Equipmnt_Amt) + sum(FedFundPlan_Equipmnt_Amt) as Equipmnt_Amt format dollar18.,    
sum(MatchFundPlan_IndirCh_Conting_Am) + sum(FedFundPlan_IndirCh_Conting_Amt) as IndirCh_Conting_Amt format dollar18.,
sum(MatchFundPlan_LandApprsl_Amt) + sum(FedFundPlan_LandApprsl_Amt) as LandApprsl_Amt format dollar18.,     
sum(MatchFundPlan_LegalExp_Amt) + sum(FedFundPlan_LegalExp_Amt) as LegalExp_Amt format dollar18.,       
sum(MatchFundPlan_OtherArchFee_Amt) + sum(FedFundPlan_OtherArchFee_Amt) as OtherArchFee_Amt format dollar18.,   
sum(MatchFundPlan_OtherMisc_Amt) + sum(FedFundPlan_OtherMisc_Amt) as OtherMisc_Amt format dollar18.,       
sum(MatchFundPlan_Personnel_Amt) + sum(FedFundPlan_Personnel_Amt) as Personnel_Amt format dollar18.,      
sum(MatchFundPlan_ProjInspFee_Amt) + sum(FedFundPlan_ProjInspFee_Amt) as ProjInspFee_Amt format dollar18.,    
sum(MatchFundPlan_RelocExp_Amt) + sum(FedFundPlan_RelocExp_Amt) as RelocExp_Amt format dollar18.,       
sum(MatchFundPlan_SiteWork_Amt) + sum(FedFundPlan_SiteWork_Amt) as SiteWork_Amt format dollar18.,      
sum(MatchFundPlan_Supplies_Amt) + sum(FedFundPlan_Supplies_Amt) as Supplies_Amt format dollar18.,      
sum(MatchFundPlan_Travel_Amt) + sum(FedFundPlan_Travel_Amt) as Travel_Amt format dollar18.
/*sum(TotCostPlan_DirCh_SubTot_Amt) as DirCh_SubTot_Amt format dollar18.,*/
/*sum(TotCostPlan_Total_Amt) as Total_Amt format dollar18.*/
, size
from MostRecent_&proj_type
group by Project_Type, size;
quit;

proc sql;
create table TotalSpend_&proj_type as
select Project_Type, 
sum(MatchFundActl_ArchFee_Amt) + sum(FedFundActl_ArchFee_Amt) as ArchFee_Amt format dollar18.,     
sum(MatchFundActl_Benefits_Amt) + sum(FedFundActl_Benefits_Amt) as Benefits_Amt format dollar18.,
sum(MatchFundActl_Constructn_Amt) + sum(FedFundActl_Constructn_Amt) as Constructn_Amt format dollar18.,
sum(MatchFundActl_Contract_Amt) + sum(FedFundActl_Contract_Amt) as Contract_Amt format dollar18., 
sum(MatchFundActl_Demolitn_Amt) + sum(FedFundActl_Demolitn_Amt) as Demolitn_Amt format dollar18., 
sum(MatchFundActl_Equipmnt_Amt) + sum(FedFundActl_Equipmnt_Amt) as Equipmnt_Amt format dollar18.,    
sum(MatchFundActl_IndirCh_Conting_Am) + sum(FedFundActl_IndirCh_Conting_Amt) as IndirCh_Conting_Amt format dollar18.,
sum(MatchFundActl_LandApprsl_Amt) + sum(FedFundActl_LandApprsl_Amt) as LandApprsl_Amt format dollar18.,     
sum(MatchFundActl_LegalExp_Amt) + sum(FedFundActl_LegalExp_Amt) as LegalExp_Amt format dollar18.,       
sum(MatchFundActl_OtherArchFee_Amt) + sum(FedFundActl_OtherArchFee_Amt) as OtherArchFee_Amt format dollar18.,   
sum(MatchFundActl_OtherMisc_Amt) + sum(FedFundActl_OtherMisc_Amt) as OtherMisc_Amt format dollar18.,       
sum(MatchFundActl_Personnel_Amt) + sum(FedFundActl_Personnel_Amt) as Personnel_Amt format dollar18.,      
sum(MatchFundActl_ProjInspFee_Amt) + sum(FedFundActl_ProjInspFee_Amt) as ProjInspFee_Amt format dollar18.,    
sum(MatchFundActl_RelocExp_Amt) + sum(FedFundActl_RelocExp_Amt) as RelocExp_Amt format dollar18.,       
sum(MatchFundActl_SiteWork_Amt) + sum(FedFundActl_SiteWork_Amt) as SiteWork_Amt format dollar18.,      
sum(MatchFundActl_Supplies_Amt) + sum(FedFundActl_Supplies_Amt) as Supplies_Amt format dollar18.,      
sum(MatchFundActl_Travel_Amt) + sum(FedFundActl_Travel_Amt) as Travel_Amt format dollar18.
/*sum(TotCostPlan_DirCh_SubTot_Amt) as DirCh_SubTot_Amt format dollar18.,*/
/*sum(TotCostPlan_Total_Amt) as Total_Amt format dollar18.*/
, size
from MostRecent_&proj_type
group by Project_Type, size;
quit;

proc sql;
create table FedBudget_&proj_type as
select Project_Type, 
sum(FedFundPlan_ArchFee_Amt) as ArchFee_Amt format dollar18.,     
sum(FedFundPlan_Benefits_Amt) as Benefits_Amt format dollar18.,
sum(FedFundPlan_Constructn_Amt) as Constructn_Amt format dollar18.,
sum(FedFundPlan_Contract_Amt) as Contract_Amt format dollar18., 
sum(FedFundPlan_Demolitn_Amt) as Demolitn_Amt format dollar18., 
sum(FedFundPlan_Equipmnt_Amt) as Equipmnt_Amt format dollar18.,    
sum(FedFundPlan_IndirCh_Conting_Amt) as IndirCh_Conting_Amt format dollar18.,
sum(FedFundPlan_LandApprsl_Amt) as LandApprsl_Amt format dollar18.,     
sum(FedFundPlan_LegalExp_Amt) as LegalExp_Amt format dollar18.,       
sum(FedFundPlan_OtherArchFee_Amt) as OtherArchFee_Amt format dollar18.,   
sum(FedFundPlan_OtherMisc_Amt) as OtherMisc_Amt format dollar18.,       
sum(FedFundPlan_Personnel_Amt) as Personnel_Amt format dollar18.,      
sum(FedFundPlan_ProjInspFee_Amt) as ProjInspFee_Amt format dollar18.,    
sum(FedFundPlan_RelocExp_Amt) as RelocExp_Amt format dollar18.,       
sum(FedFundPlan_SiteWork_Amt) as SiteWork_Amt format dollar18.,      
sum(FedFundPlan_Supplies_Amt) as Supplies_Amt format dollar18.,      
sum(FedFundPlan_Travel_Amt) as Travel_Amt format dollar18.
/*sum(TotCostPlan_DirCh_SubTot_Amt) as DirCh_SubTot_Amt format dollar18.,*/
/*sum(TotCostPlan_Total_Amt) as Total_Amt format dollar18.*/
, size
from MostRecent_&proj_type
group by Project_Type, size;
quit;

proc sql;
create table FedSpend_&proj_type as
select Project_Type, 
sum(FedFundActl_ArchFee_Amt) as ArchFee_Amt format dollar18.,     
sum(FedFundActl_Benefits_Amt) as Benefits_Amt format dollar18.,
sum(FedFundActl_Constructn_Amt) as Constructn_Amt format dollar18.,
sum(FedFundActl_Contract_Amt) as Contract_Amt format dollar18., 
sum(FedFundActl_Demolitn_Amt) as Demolitn_Amt format dollar18., 
sum(FedFundActl_Equipmnt_Amt) as Equipmnt_Amt format dollar18.,    
sum(FedFundActl_IndirCh_Conting_Amt) as IndirCh_Conting_Amt format dollar18.,
sum(FedFundActl_LandApprsl_Amt) as LandApprsl_Amt format dollar18.,     
sum(FedFundActl_LegalExp_Amt) as LegalExp_Amt format dollar18.,       
sum(FedFundActl_OtherArchFee_Amt) as OtherArchFee_Amt format dollar18.,   
sum(FedFundActl_OtherMisc_Amt) as OtherMisc_Amt format dollar18.,       
sum(FedFundActl_Personnel_Amt) as Personnel_Amt format dollar18.,      
sum(FedFundActl_ProjInspFee_Amt) as ProjInspFee_Amt format dollar18.,    
sum(FedFundActl_RelocExp_Amt) as RelocExp_Amt format dollar18.,       
sum(FedFundActl_SiteWork_Amt) as SiteWork_Amt format dollar18.,      
sum(FedFundActl_Supplies_Amt) as Supplies_Amt format dollar18.,      
sum(FedFundActl_Travel_Amt) as Travel_Amt format dollar18.
/*sum(TotCostPlan_DirCh_SubTot_Amt) as DirCh_SubTot_Amt format dollar18.,*/
/*sum(TotCostPlan_Total_Amt) as Total_Amt format dollar18.*/
, size
from MostRecent_&proj_type
group by Project_Type, size;
quit;

proc transpose
data=FedSpend_&proj_type
out=FedSpend_&proj_type;
id size;
run;

proc transpose
data=Totalbudget_&proj_type
out=Totalbudget_&proj_type;
id size;
run;

proc transpose
data=Fedbudget_&proj_type
out=Fedbudget_&proj_type;
id size;
run;

proc transpose
data=TotalSpend_&proj_type
out=TotalSpend_&proj_type;
id size;
run;

proc sql;
create table FedSpend_&proj_type._final as
select a.implan_440, a.low*b.low as Low, a.Medium*b.medium as Medium, a.high*b.high as High
from datamap_&proj_type as a left join FedSpend_&proj_type as b 
on a.Expend_sector=b._Name_;
quit;

proc sql;
create table FedSpend_&proj_type._final as
select implan_440, sum(low + medium + high) as &proj_type
from FedSpend_&proj_type._final
group by implan_440;
quit;

proc sql;
create table TotBudg_&Proj_type._final as
select a.implan_440, a.low*b.low as Low, a.Medium*b.medium as Medium, a.high*b.high as High
from datamap_&proj_type as a left join Totalbudget_&proj_type as b 
on a.Expend_sector=b._Name_;
quit;

proc sql;
create table TotBudg_&Proj_type._final as
select implan_440, sum(low + medium + high) as &proj_type
from TotBudg_&Proj_type._final
group by implan_440;
quit;

proc sql;
create table FedBudg_&Proj_type._final as
select a.implan_440, a.low*b.low as Low, a.Medium*b.medium as Medium, a.high*b.high as High
from datamap_&proj_type as a left join Fedbudget_&proj_type as b 
on a.Expend_sector=b._Name_;
quit;

proc sql;
create table FedBudg_&Proj_type._final as
select implan_440, sum(low + medium + high) as &proj_type
from FedBudg_&Proj_type._final
group by implan_440;
quit;

proc sql;
create table TotalSpend_&Proj_type._final as
select a.implan_440, a.low*b.low as Low, a.Medium*b.medium as Medium, a.high*b.high as High
from datamap_&proj_type as a left join TotalSpend_&proj_type as b 
on a.Expend_sector=b._Name_;
quit;

proc sql;
create table TotalSpend_&Proj_type._final as
select implan_440, sum(low + medium + high) as &proj_type
from TotalSpend_&Proj_type._final
group by implan_440;
quit;

proc sql;
create table TotBudg_&Proj_type._final as
select IMPLAN_440, &proj_type,
0 as Employment label="Emplyoment", 0 as employeecomp label="Employee Compensation",
0 as Prop_Income label "Proprietor Income",
2009 as EventYear Label="EventYear", "No" as Retail Label = "Retail",
"100%" as LocDirPur Label="Local Direct Purhcase"
from TotBudg_&Proj_type._final
order by &proj_type;
quit;

proc sql;
create table TotalSpend_&Proj_type._final as
select IMPLAN_440, &proj_type,
0 as Employment label="Emplyoment", 0 as employeecomp label="Employee Compensation",
0 as Prop_Income label "Proprietor Income",
2009 as EventYear Label="EventYear", "No" as Retail Label = "Retail",
"100%" as LocDirPur Label="Local Direct Purhcase"
from TotalSpend_&Proj_type._final
order by &proj_type;
quit;

proc sql;
create table FedBudg_&Proj_type._final as
select IMPLAN_440, &proj_type,
0 as Employment label="Emplyoment", 0 as employeecomp label="Employee Compensation",
0 as Prop_Income label "Proprietor Income",
2009 as EventYear Label="EventYear", "No" as Retail Label = "Retail",
"100%" as LocDirPur Label="Local Direct Purhcase"
from FedBudg_&Proj_type._final
order by &proj_type;
quit;

proc sql;
create table FedSpend_&Proj_type._final as
select IMPLAN_440, &proj_type,
0 as Employment label="Emplyoment", 0 as employeecomp label="Employee Compensation",
0 as Prop_Income label "Proprietor Income",
2009 as EventYear Label="EventYear", "No" as Retail Label = "Retail",
"100%" as LocDirPur Label="Local Direct Purhcase"
from FedSpend_&Proj_type._final
order by &proj_type;
quit;
%mend BudgetTables;

/*********************************************************************/
/*Run the macro creating the tables for PCC-SBA grants and CCI grants*/
/*********************************************************************/
%BudgetTables(PCC_SBA);
%BudgetTables(CCI);

/*********************************************************************/
/*Macro that formats the tables generated above so they are able to be*/
/*read into IMPLAN. Once formatted, they are written as excel files and*/ 
/*saved to the folder designated at the beginning of this program*/
/*********************************************************************/
%macro FormatForImplan(table,proj_type);
/**************************************************************
automatically closes the prompt window after the command has
completed. The NOXSYNC instructs the system to process as soon 
as the command is issued.
**************************************************************/
options noxwait noxsync;


x copy "&IO_Directory.\IO_Template.xls"
		"&IO_Directory.\IO_&table._&proj_type..xls";


/*****************************************************************
Sleep is used to allow the Excel window to initialize prior to 
attempting to open the file. The length of the wait period can 
be adjusted up or down as needed.
******************************************************************/
data _null_;
x=sleep(3);
run;


%let command=&IO_Directory.\IO_&table._&proj_type..xls;
%put &command;

Data _null_;
 char = "'" || '"' || "&command" || '"' || "'";
 call symput('macvar',char);
Run;

%put &macvar;


x &macvar;

data _null_;
x=sleep(3);
run;


filename xl_name dde 
	"Excel|Industry Change!R2C2:R2C2";

filename xlout dde 
	"Excel|Industry Change!R5C1:R20C8";

%put "&table._&proj_type";


data _null_;
file xl_name;
put "&table._&proj_type";
run;


data _null_;
file xlout;
set &table._&proj_type._final;
put implan_440 &proj_type employment employeecomp Prop_Income EventYear Retail LocDirPur;
run;


 filename ddecmds dde "Excel|system"; 

data _null_; 
file ddecmds; 
put '[error(false)]'; 
put "[save.as(""&command."")]"; 
put '[error(true)]'; 
put '[file.close()]'; 
put '[quit()]'; 
run;
%mend FormatForImplan;

%FormatForImplan(Totbudg,PCC_SBA);
%FormatForImplan(TotalSpend,PCC_SBA);
%FormatForImplan(Fedspend,PCC_SBA);
%FormatForImplan(fedbudg,PCC_SBA);

%FormatForImplan(Totbudg,CCI);
%FormatForImplan(TotalSpend,CCI);
%FormatForImplan(Fedspend,CCI);
%FormatForImplan(fedbudg,CCI);

/***************************************************************/
/*Macro to Create a total budget, fed budget, total spend and fed 
spend tables with ALL grants (PCC_SBA and CCI)*/
/***************************************************************/
%macro AllGrantTables(fund_type);
data &fund_type.1;
set &fund_type._cci_final;
rename CCI=Funds;
run;

data &fund_type.2;
set &fund_type._pcc_sba_final;
rename PCC_SBA=Funds;
run;

proc append
base=&fund_type.1 
data=&fund_type.2;
run;

proc sql;
create table &fund_type._all_final as
select implan_440, sum(funds) as AllGrants format dollar18., employment, employeecomp, prop_income, eventyear, retail, LocDirPur
from &fund_type.1
group by implan_440, employment, employeecomp, prop_income, eventyear, retail, LocDirPur
order by AllGrants;
quit; 
%mend AllGrantTables;

%AllGrantTables(Totbudg);
%AllGrantTables(Totalspend);
%AllGrantTables(Fedbudg);
%AllGrantTables(Fedspend);

%FormatForImplan(Totbudg,all);
%FormatForImplan(Totalspend,all);
%FormatForImplan(Fedbudg,all);
%FormatForImplan(Fedspend,all);
