# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"),
       echo = TRUE)



# Load Prepared Data ####

# Grants
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)

# Reorder factor 
grants[, Case_Study := factor(Case_Study, rev(levels(Case_Study)))]

# CCI Progress
progress.rda <- file.path(parent.dir, "Prepared Data", "CCI Progress.rda")
load(progress.rda)
head(network_progress)



# Figure 5. Interconnection Points by Quarter ####

# Lookup interconnection points
interconnect <- network_progress[grants[Grant_Type == "CCI"]]

# Drop excluded and defunded
interconnect <- interconnect[Excluded == ""][Defunded == ""]

# Roll up
interconnect <- interconnect[, list(points = sum(InterconnectPoints_Num),
                                    rolled = any(rolled)), 
                             keyby = list(quarter, Case_Study)]

# Positions for "Estimated"
interconnect[, qsum := sum(points), by = quarter]
interconnect[rolled & Case_Study == "Evaluation Study Sample", 
             epos := points / 2 + (qsum - points)]
interconnect[rolled & Case_Study != "Evaluation Study Sample", 
             epos := points / 2]

# Trial and error determines full or abbreviated "Estimated"
interconnect[, elab := "Estimated"]

# Plot
(inter_points <- ggplot(interconnect, aes(quarter, points)) + 
  geom_bar(stat = "identity", aes(fill = Case_Study, order = Case_Study)) + 
  scale_fill_manual(values = c("black", "#800000")) + 
  geom_text(aes(y = epos, label = elab), color = "white", angle = 90,
            size = 5) +
  scale_x_date(label = date_format("%B\n%Y")) + 
  scale_y_continuous(label = comma) + 
  theme_btop() + 
  theme(axis.title = element_blank()))

# Save
ggsave(file.path(sec4, "Figure 5.png"), inter_points, width = 12.2, height = 7)

# Figure talk
dcast(interconnect, quarter ~ Case_Study, sum, margins = "Case_Study", 
      value.var = "points")
