# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load analysis ####

# Effects on Availability
effects.rda <- file.path(parent.dir, "Statistical Analysis", 
                         "Effect on Availability.rda")
load(effects.rda)
head(effects)
head(did.overall)



# Table. Estimated BTOP Effect on Broadband Availability ####

# Reshape
d <- as.data.table(lapply(did.overall[J("NTIA", "Availability", "Primary")],
                          as.character))
d <- melt(d, id.vars = key(did.overall))[, variable := as.character(variable)]

# Add row labels
d[grep("-in-", variable), row := variable]
d[is.na(row) & grepl("Diff", variable), row := "Difference"]
d[is.na(row), row := Release]

# Clean up
d[, tc := factor(grepl("Control", variable), 
                 labels = c("Treatment", "Control"))]
d[, value := as.numeric(value)]

# Reshape
est_effect_ntia_avail <- Dcast(
  d[!(grepl("Diff", row) & Release == "2011-06-30")], row ~ tc, 
  value.var = "value")

# Better labels
est_effect_ntia_avail[row == "2011-06-30", row := "June 30, 2011"]
est_effect_ntia_avail[row == "2013-06-30", row := "June 30, 2013"]

# Format values
est_effect_ntia_avail[, 2:3 := lapply(lapply(.SD, "*", 100), sprintf,
                                      fmt = "%.2f%%"), .SDcols = 2:3]

# Rename
setnames(est_effect_ntia_avail, "row", "Availability")

# Write to file
write.xlsx(est_effect_ntia_avail, file.path(sec4, "Table 12.xlsx"), 
           row.names = FALSE)

# Table talk - How many people?
setkey(effects, definition, adjustment, match.type)
effects[J("NTIA", "Availability", "Primary")][
  , list(`Evaluation Study Sample`, `All BTOP`)]
