# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load Prepared Data ####

# Grants
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)

# PCC Equipment
equipment.rda <- file.path(parent.dir, "Prepared Data", "PCC Equipment.rda")
load(equipment.rda)
head(inst_upgr)



# Figure 8. Cumulative PCC Hardware Installations and Upgrades ####

# Lookup installations and upgrades
install <- inst_upgr[grants[Grant_Type == "PCC"], allow.cartesian = TRUE]

# Drop defunded
install <- install[Defunded == ""]

# Roll up
vars <- c("WorkstatnInstall_Num", "ConnectUpgrade_Num", "ConnectEstablish_Num", 
          "rolled")
install <- install[, lapply(.SD, sum), keyby = list(quarter, Case_Study), 
                   .SDcols = vars]
install[, rolled := rolled > 0]

# Reshape
install <- melt(install, id.vars = c("quarter", "Case_Study", "rolled"))

# Positions for "Estimated"
install[, qsum := sum(value), by = list(quarter, variable)]
install[rolled & Case_Study == "Evaluation Study Sample", epos := value / 2 +
          (qsum - value)]
install[rolled & Case_Study != "Evaluation Study Sample", epos := value / 2]

# Trial and error determines full or abbreviated "Estimated"
install[, elab := "Estimated"]
install[Case_Study == "Evaluation Study Sample", elab := "Est."]

# Factor labels
install[, variable := factor(variable, vars[-4], c(
  "Workstations Installed", "Broadband Connections Upgraded", 
  "Wireless Broadband Connections Established"))]
install[, Case_Study := factor(Case_Study, rev(levels(Case_Study)))]

# Plot
(installations <- ggplot(install, aes(quarter, value)) + 
   facet_wrap(~ variable, ncol = 1, scales = "free_y") +
   geom_bar(stat = "identity", aes(fill = Case_Study, order = Case_Study)) + 
   scale_fill_manual(values = c("black", "#800000")) + 
   geom_text(aes(y = epos, label = elab), color = "white", angle = 90, 
             size = 5) +
   scale_x_date(label = date_format("%B\n%Y")) + 
   scale_y_continuous(label = comma) + 
   theme_btop() + 
   theme(axis.title = element_blank()))

# Save
ggsave(file.path(sec6, "Figure 8.png"), installations, width = 12.2, 
       height = 12.2)

# Figure talk
dcast(install, variable + quarter ~ Case_Study, sum, margins = "Case_Study", 
      value.var = "value")
