# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load intermediate files ####

# Grants list
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)

# Labor force statistics
labor.rda <- file.path(parent.dir, "Prepared Data",
                       "PCC and SBA Labor Force Statistics.rda")
load(labor.rda)
head(labor_force)

# Subscribers
subscr.rda <- file.path(parent.dir, "Prepared Data", 
                        "SBA Subscribers.rda")
load(subscr.rda)
head(sba_subscr_total)

# Job search training
job.rda <- file.path(parent.dir, "Prepared Data",
                     "PCC and SBA Job Search Training Summary.rda")
load(job.rda)
head(job_search)



# Calculations ####

# Kuhn and Mansour (2013) estimated that unemployment durations are 24 percent 
# shorter for Internet job searchers than offline job searchers.

# Data
sba.w.1 <- grants[Grant_Type == "SBA"][Defunded == ""] # SBA grants
sba.w.1 <- labor_force[sba.w.1] # Labor force stats
sba.w.1 <- sba_subscr_total[sba.w.1] # New subscribers
sba.w.1 <- job_search[sba.w.1] # Job search trainees

# Number of new subscribers who search
sba.w.1[, searchers_newsub := subscr_cum * labor_participation *
          unemployment_rate]

# Number of searchers (new subscribers + trainees)
sba.w.1[, `New Internet job searchers` := searchers_newsub +
          replace(participants, is.na(participants), 0)]

# Total decrease in unemployment duration
sba.w.1[, `Decreased duration` := `New Internet job searchers` * 
          avg_duration * .237]

# Total decrease * average wage
sba.w.1[, `Total Economic Benefit` := (`Decreased duration` * 
                                         (min_wage * 40)) / 1e6]



# Results ####

# Job searchers and unemployment reduction
search_reduct <- tabular(Heading("Estimate") * (
  `New Internet job searchers` + `Decreased duration`) * Heading() * sum * 
    Format(formatC(digits = 0, big.mark = ",", format = "f")) ~ 
    Heading() * Case_Study + Heading("Total") * 1, sba.w.1)
(search_reduct <- search_reduct[, 3])

# Total benefit due to unemployment reduction
(totalben <- tabular(`Total Economic Benefit` * Heading() * sum * Format(
  formatC(digits = 0, big.mark = ",", format = "f")) ~ 
    Heading() * Case_Study + Heading("Total") * 1, sba.w.1))



# Write to files ####

# Job searchers and unemployment reduction 
write.xlsx.tabular(search_reduct, file.path(appC, "SBA.W.1 - Table 43.xlsx"))

# Total benefit due to unemployment reduction - by case study
write.xlsx.tabular(totalben, file.path(appC, "SBA.W.1 - Table F.xlsx"))
