# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load Prepared Data ####

# NBM Population Statistics
nbm.rda <- file.path(parent.dir, "Prepared Data", 
                     "NBM Population Statistics.rda")
load(nbm.rda)
head(availability)

# Treatment and Potential Control Counties
treat.control.rda <- file.path(parent.dir, "Prepared Data",
                               "Treatment and Potential Control Counties.rda")
load(treat.control.rda)
head(control.elimination)
head(treat.control.status)



# Figure. Distribution of Rural Percentage of Population in Treatment and 
# Potential Control Counties, June 2011 ####

# Merge
d <- treat.control.status[availability, list(Group, ppop_rural_2011_06)][
  Group != "Removed Counties"]
setnames(d, "ppop_rural_2011_06", "rural_pct")

# Cut percentage of population into 10% ranges
d[, Rurality := cut(rural_pct, seq(0, 1, by = .1), include.lowest = TRUE)]
levs <- c("0% to 10%", "10% to 20%", "20% to 30%", "30% to 40%", "40% to 50%", 
          "50% to 60%", "60% to 70%", "70% to 80%", "80% to 90%", "90% to 100%")
levels(d$Rurality) <- levs
d[, Rurality := as.character(Rurality)]

# If rurality is 100%, set rurality group to that
d[rural_pct == 1, Rurality := "100%"]
d[, Rurality := factor(Rurality, levels = c(levs, "100%"))]

# Stacked bar plot with labels
(dist_rural_pop <- ggplot(d, aes(Rurality)) + 
   geom_bar(aes(fill = Group)) + 
   geom_text(data = d[, .N, by = Rurality], aes(y = N + 11, label = N), 
             size = 6) +
   scale_fill_manual(values = c("#800000", "black")) + 
   labs(y = "Number of Counties", x = "Rural Percentage of Population") + 
   theme_btop() + 
   theme(axis.text.x = element_text(angle = 45, hjust = 1, vjust = 1)))

# Save to file
rural.dist <- file.path(appD, "Figure 11.png")
ggsave(rural.dist, dist_rural_pop, width = 12.2, height = 6)

# What's the mean w/o 100%? (peripherally mentioned in figure talk)
d[rural_pct < 1, mean(rural_pct)]
# 0.4865959
