# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code",
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code",
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load analysis ####

# Effects on Availability
effects.rda <- file.path(parent.dir, "Statistical Analysis", 
                         "Effect on Availability.rda")
load(effects.rda)
head(effects)
head(did.overall)



# Figure. Resampled Effect and Confidence Bands for NTIA Broadband 
# Availability ####

# Bar plot
(dist_effect_base <- ggplot(base.replications[1], aes(replicates)) + 
   geom_bar(data = base.replications, fill = "black", binwidth = .001) + 
   geom_vline(aes(xintercept = lower), linetype = 2) + 
   geom_vline(aes(xintercept = upper), linetype = 2) + 
   geom_vline(aes(xintercept = effect), color = "#800000", size = 1.5) +
   scale_x_continuous("Effect", label = percent, breaks = pretty_breaks(10)) +
   ylab("Number of Replications") +
   theme_btop())

# Write to file
ggsave(file.path(appD, "Figure 13.png"), dist_effect_base, width = 10, 
       height = 5)

# Figure talk
base.replications[1, list(effect, lower, upper)]
