# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code",
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load analysis ####

# Effects on Availability
effects.rda <- file.path(parent.dir, "Statistical Analysis",
                         "Effect on Availability.rda")
load(effects.rda)
head(effects)
head(did.overall)



# Table 53. Availability Rates, Differences, and Difference-in-Differences for 
# Matched Pair Groups ####

# Reshape diff-in-diff
d <- melt(did.overall, id.vars = 1:4)
setnames(d, "Release", "rel")

# Add descriptors
d[, Definition := definition]
d[, Match := match.type]
d[grep("-in-", variable), c("Group", "Release") := "Difference-in-Differences"]
d[grep("Treatment", variable), Group := "Treatment"]
d[grep("Control", variable), Group := "Control"]
d[grep("Difference$", variable), Release := "Difference"]
d[is.na(Release), Release := as.character(year(rel))]
d[, Group := factor(Group, c("Treatment", "Control", 
                             "Difference-in-Differences"))]
d[, Release := factor(Release, c("2011", "2013", "Difference", 
                                 "Difference-in-Differences"))]
d <- d[!(grepl("D", Release) & year(rel) == 2011)]

# Reshape
d <- tabular(Definition * Match * Group * Release ~ Heading() * adjustment * 
               Heading() * value * Heading() * identity, d)
d <- as.data.frame(as.matrix(d))
names(d) <- d[1, ]
d <- d[-1, ]
avail_diff_did <- d[complete.cases(d), ]
avail_diff_did[5:7] <- lapply(lapply(lapply(avail_diff_did[5:7], as.numeric),
                                     "*", 100), sprintf, fmt = "%.2f%%")
avail_diff_did

# Write to file
write.xlsx(avail_diff_did, file.path(appD, "Table 51.xlsx"), row.names = FALSE)
