# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Functions.R"), echo = TRUE)



# Load analysis ####

# Effects on Availability
effects.rda <- file.path(parent.dir, "Statistical Analysis", 
                         "Effect on Availability.rda")
load(effects.rda)
head(effects)
head(did.overall)



# Table 53. Difference-in-Difference Estimates and Lower and Upper Confidence 
# Values for Matched Pair Groups ####

# Reshape and add better labels
d <- melt(effects.intervals, id.vars = key(effects.intervals))
d[, variable := factor(variable, c("lower", "effect", "upper"), 
                       c("L95", "Est.", "U95"))]
d[, value := value * 100]

# Table
(did_int <- tabular(Heading() * match.type * Heading() * adjustment ~ 
                  Heading() * definition * Heading() * variable * Heading() * 
                    value * Heading() * identity * Format(sprintf("%.2f%%")), 
                  d))

# Write to file
write.xlsx.tabular(did_int, file.path(appD, "Table 53.xlsx"))
