# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code",
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)


# Load packages (install if necessary) ####
packages <- c("data.table", "xlsx", "lubridate")
for (x in setdiff(packages, installed.packages())) install.packages(x)
for (x in packages) library(x, character.only = TRUE)


# Convenience (wrapper) functions to reduce code clutter ####
Read.xlsx2 <- function(...) as.data.table(read.xlsx2(...))



# Load Prepared Data ####

# Grants
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)



# Case study connected CAIs ####

# Read file
cs.cais <- file.path(parent.dir, "Input Files",
                     "CCI Connected CAIs in Evaluation Study Reports.xlsx")
conn_cais <- Read.xlsx2(cs.cais, sheetIndex = 1, 
                        colClasses = replace(rep("character", 4), 2, "numeric"))

# Add quarter column as date
conn_cais[, quarter := paste(Year_Desc, 
                             as.numeric(substr(Quarter_Cd, 2, 2)) * 3, 1)]
conn_cais[, quarter := as.Date(quarter, "%Y %m %d") + months(1) - days(1)]

# Key
setkey(conn_cais, Award_Num, quarter)



# Save ####
cs.cais.rda <- file.path(parent.dir, "Prepared Data",
                         "CCI Evaluation Study Sample CAIs.rda")
save(conn_cais, file = cs.cais.rda)



# Write ####
cs.cais.xlsx <- file.path(parent.dir, "Prepared Data", 
                          "CCI Evaluation Study Sample CAIs.xlsx")
write.xlsx2(grants[conn_cais], cs.cais.xlsx, row.names = FALSE)
