# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load Prepared Data ####

# Grants
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)



# ASR-collected speed and pricing data for CAIs connected by Evaluation Study 
# Sample grantees ####

# Read file
prspd.file <- file.path(
  parent.dir, "Input Files", 
  "CCI Evaluation Study Sample Connected CAI Collected Speed and Pricing Data.xlsx")
price_speed <- Read.xlsx2(prspd.file, sheetIndex = 1, colClasses = c(
  rep("character", 3), rep("numeric", 8), "character"))
price_speed[, Notes := NULL]

# Rename columns
setnames(price_speed, names(price_speed)[-1], c(
  "anchorname", "category", "speed_before", "price_before", "price_mbps_before",
  "speed_after", "price_after", "price_mbps_after", "speed_increase", 
  "price_decrease"))

# Replace NaN with NA
price_speed[, 4:11 := Map(replace, .SD, lapply(.SD, is.nan), NA_real_),
            .SDcols = 4:11]

# Factor
categories <- c("School (K-12)", "University, College, or Other Postsecondary", 
                "Medical/Healthcare", "Library", "Other Community Support", 
                "Public Safety")
price_speed[, category := factor(category, categories)]

# Key
setkey(price_speed, Award_Num)



# Save ####
prspd.rda <- file.path(parent.dir, "Prepared Data", 
                       "CCI Speed and Pricing.rda")
save(price_speed, file = prspd.rda)



# Save ####
prspd.xlsx <- file.path(parent.dir, "Prepared Data", 
                        "CCI Speed and Pricing.xlsx")
write.xlsx(grants[price_speed], prspd.xlsx, row.names = FALSE)
