# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code",
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Grant list ####

# Read file
grants.file <- file.path(parent.dir, "Input Files", 
                         "List of Awarded BTOP Grants.xlsx")
grants <- Read.xlsx2(grants.file, sheetIndex = 1)

# Turn character columns into factors
grants[, Grant.Type := factor(Grant.Type, c("PCC", "SBA", "CCI"))]
grants[, Case.Study := factor(Case.Study, c("Evaluation Study Sample", 
                                            "Rest of BTOP"))]
grants[, Excluded := factor(Excluded.From.Study)][, Excluded.From.Study := NULL]
grants[, Defunded := factor(Defunded)]

# Rename
setnames(grants, names(grants), gsub("\\.", "_", names(grants)))

# Key
setkey(grants, Award_Num)



# Save ####
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
save(grants, file = grants.rda)



# Write ####
grants.xlsx <- file.path(parent.dir, "Prepared Data", "Grants.xlsx")
write.xlsx2(grants, grants.xlsx, row.names = FALSE)
