# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code",
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code",
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load Prepared Data ####

# ACS 2010
acs.rda <- file.path(parent.dir, "Prepared Data", "ACS 2010.rda")
load(acs.rda)
head(acs10)



# Read data ####

# NBM households
nbm.hhu.file <- file.path(
  parent.dir, "Input Files",
  "NBM Statistics, 2011-06-30 and 2013-06-30 - Housing Units.xlsx")
hhu <- Read.xlsx2(nbm.hhu.file, sheetIndex = 1, 
                  colClasses = c(rep("character", 4), rep("numeric", 7)))



# Combine ####

# Total housing units, 2011
households <- hhu[year == "2011", list(hunits = total), keyby = fips]

# Household income
households[acs10, household_income := household_income]

# Replace missing household income with median
households[, household_income := replace(
  household_income, is.na(household_income), 
  median(household_income, na.rm = TRUE))]



# Save ####
households.rda <- file.path(parent.dir, "Prepared Data", 
                            "Household Statistics.rda")
save(households, file = households.rda)



# Write ####
households.xlsx <- file.path(parent.dir, "Prepared Data",
                             "Household Statistics.xlsx")
write.xlsx2(households, households.xlsx, row.names = FALSE)
