# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Read data ####

# LAU 
lau.file <- file.path(parent.dir, "Input Files", 
                      "BLS Local Area Unemployment Statistics - 2011.xlsx")
lau <- Read.xlsx2(lau.file, colClasses = c("character", rep("numeric", 4)),
                  sheetIndex = 1)
setkey(lau, fips)

# CEW 
cew.file <- file.path(parent.dir, "Input Files", 
                      "BLS Census of Employment and Wages - 2011.xlsx")
cew <- Read.xlsx2(cew.file, sheetIndex = 1, 
                  colClasses = c("character", "numeric"))
setkey(cew, fips)



# Combine ####

# Merge LAU and CEW (county level)
labor_force <- merge(lau, cew, all = TRUE)

# Clean up
labor_force <- labor_force[, list(fips, employed, avg_ann_wage)]
setkey(labor_force, fips)



# Save ####
labor.force.rda <- file.path(parent.dir, "Prepared Data",
                             "Labor Force Statistics.rda")
save(labor_force, file = labor.force.rda)



# Write ####
labor.force.xlsx <- file.path(parent.dir, "Prepared Data", 
                              "Labor Force Statistics.xlsx")
write.xlsx2(labor_force, labor.force.xlsx, row.names = FALSE)
