# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code",
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load Prepared Data ####

# Grants
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)



# Enretpreneurship training ####

# Read file
entrep.file <- file.path(parent.dir, "Input Files", 
                         "PCC and SBA Entrepreneurship Training.xlsx")
entrepreneurship <- Read.xlsx2(entrep.file, sheetIndex = 1)
entrepreneurship[, participants := as.numeric(Participants)]

# Roll up participants
entrepreneurship <- entrepreneurship[, list(participants = sum(participants)), 
                                     keyby = Award_Num]



# Save to file ####
entrain.rda <- file.path(parent.dir, "Prepared Data", 
                         "PCC and SBA Entrepreneurship Training Summary.rda")
save(entrepreneurship, file = entrain.rda)



# Add grant info and write to file ####
entrain.xlsx <- file.path(parent.dir, "Prepared Data", 
                          "PCC and SBA Entrepreneurship Training Summary.xlsx")
write.xlsx(grants[entrepreneurship], entrain.xlsx, row.names = FALSE)
