# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load grant list ####
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)



# Read and combine data ####

# Read Evaluation Study Sample service areas
cssa.file <- file.path(
  parent.dir, "Input Files",
  "PCC and SBA Service Areas - Evaluation Study Sample.xlsx")
cssa <- read.xlsx2(cssa.file, sheetIndex = 1, colClasses = "character")

# Read rest of BTOP service areas
rbsa.file <- file.path(parent.dir, "Input Files", 
                       "PCC and SBA Service Areas - Rest of BTOP.xlsx")
rbsa <- read.xlsx2(rbsa.file, sheetIndex = 1, colClasses = "character")

# Extract columns and combine
k <- c("Award_Num", "FIPS")
service.areas <- unique(as.data.table(rbind(cssa[k], rbsa[k])))

# Rename and key
setnames(service.areas, "FIPS", "fips")
setkey(service.areas, fips)



# Other levels ####

# Service area counties - used for some statistics
sa.county.level <- copy(service.areas)
sa.county.level[, fips := substr(fips, 1, 5)]
setkey(sa.county.level, fips, Award_Num)
sa.county.level <- unique(sa.county.level)

# Service area states - used for some statistics
sa.state.level <- copy(service.areas)
sa.state.level[, fips := substr(fips, 1, 2)]
setkey(sa.state.level, fips, Award_Num)
sa.state.level <- unique(sa.state.level)

# County-level service areas only - for convenience
county.areas <- service.areas[nchar(fips) == 5]

# Tract-level service areas only - for convenience
tract.areas <- service.areas[nchar(fips) > 5]



# Save to file ####
service.rda <- file.path(parent.dir, "Prepared Data",
                         "PCC and SBA Service Areas.rda")
save(service.areas, sa.county.level, sa.state.level, county.areas, tract.areas,
     file = service.rda)



# Add grant info columns and write to files ####

# Lookups
service.areas <- grants[setkey(service.areas, Award_Num)]
sa.county.level <- grants[setkey(sa.county.level, Award_Num)]
sa.state.level <- grants[setkey(sa.state.level, Award_Num)]
county.areas <- grants[setkey(county.areas, Award_Num)]
tract.areas <- grants[setkey(tract.areas, Award_Num)]

# Writes
service.file <- file.path(parent.dir, "Prepared Data", 
                          "PCC and SBA Service Areas.xlsx")
write.xlsx2(service.areas, service.file, "All Areas", row.names = FALSE)
write.xlsx2(sa.county.level, service.file, "All at County Level", 
            row.names = FALSE, append = TRUE)
write.xlsx2(sa.state.level, service.file, "All at State Level", 
            row.names = FALSE, append = TRUE)
write.xlsx2(county.areas, service.file, "County Areas",
            row.names = FALSE, append = TRUE)
write.xlsx2(tract.areas, service.file, "Tract Areas", 
            row.names = FALSE, append = TRUE)
