# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"),
       echo = TRUE)



# Load Prepared Data ####

# Grants
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)



# CAC data ####

# Read 2012 file
cac12.file <- file.path(parent.dir, "Input Files", "CAC Data - 2012.xls")
sba_cac_12 <- Read.xlsx2(cac12.file, sheetName = "SBA Programs Data", 
                         colClasses = "character")

# Select columns
sba_locs <- sba_cac_12[, list(
  Award_Num = Award.ID, Site.Name, Institution.Type, Organization.Type)]
setkey(sba_locs, Award_Num)

# Some are misreported as Institution.Type == "CAI"
sba_locs[Institution.Type == "CAI", Institution.Type := Organization.Type]

# Factor and collapse levels
x <- sba_locs[, factor(Institution.Type)]
levels(x)[levels(x) %in% c(
  "Community Based Organization", "community Based Organization (CBO)", 
  "Community Based Organization (CBO)")] <- "Community-Based Organization"
levels(x)[levels(x) %in% c("For-Profit Entity", "For-Profit Organization")] <- 
  "For-Profit Organization"
levels(x)[levels(x) %in% c("Government", "Government Facility")] <- 
  "Government Facility"
levels(x)[levels(x) %in% c(
  "Higher Ed", "Institition of Higher Learning", 
  "Institute of Higher Education", "Institution of Higher Education",
  "Institution of Higher Learning")] <- "Institution of Higher Education"
levels(x)[levels(x) %in% c("Hospital", "Medical or Healthcare Provider")] <- 
  "Medical or Healthcare Provider"
levels(x)[levels(x) %in% c(
  "Non-Profit", "Non-Profit Entity", "Non-Profit Organization", 
  "Nonprofit")] <- "Nonprofit Organization"
levels(x)[levels(x) %in% c("Public Housing", "Public Housing ")] <-
  "Public Housing"
levels(x)[levels(x) %in% c(
  "School", "school (K-12)", "School (k-12)", "School (K-12)",
  "Educational Institution")] <- "School (K-12)"
levs <- c(
  "Community-Based Organization", "Community College", 
  "For-Profit Organization", "Government Facility",
  "Institution of Higher Education", "Library", 
  "Medical or Healthcare Provider", "Nonprofit Organization", "Public Housing", 
  "Public Safety", "School (K-12)", "Tribal")
levels(x)[!levels(x) %in% levs] <- "Other"
sba_locs[, type := factor(x, c(levs, "Other"))]

# Select columns
sba_locs <- sba_locs[, list(Award_Num, Site.Name, type)]
setkey(sba_locs, Award_Num)



# Save ####
locs.rda <- file.path(parent.dir, "Prepared Data", "SBA Locations.rda")
save(sba_locs, file = locs.rda)



# Write ####
locs.xlsx <- file.path(parent.dir, "Prepared Data", "SBA Locations.xlsx")
write.xlsx2(grants[sba_locs], locs.xlsx, row.names = FALSE)
