# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Functions.R"), echo = TRUE)




# Load analysis ####

# Effects on Availability
effects.rda <- file.path(parent.dir, "Statistical Analysis",
                         "Effect on Availability.rda")
load(effects.rda)
head(effects)



# Load Prepared Data ####

# Adoption Rates
adoption.rda <- file.path(
  parent.dir, "Prepared Data", 
  "Rates of Adoption by Households with Availability.rda")
load(adoption.rda)
head(adoption)

# Treatment and Potential Control Counties.rda
counties.rda <- file.path(parent.dir, "Prepared Data",
                          "Treatment and Potential Control Counties.rda")
load(counties.rda)
head(btop)



# BTOP table: county-level effects and adoption ####

# All definitions * all adjustments * all match types * all counties
extrapolate <- CJ(definition = unique(effects$definition), 
                  adjustment = unique(effects$adjustment), 
                  match.type = unique(effects$match.type),
                  fips = unique(btop$fips))

# Look up effects for definition * adjustment * match.type
setkey(effects, definition, adjustment, match.type)
extrapolate[effects, effect := `Difference-in-Differences`]

# Look up adoption rate
setkey(extrapolate, fips, adjustment)
extrapolate[adoption, adoption_rate := adoption_rate, allow.cartesian = TRUE]

# Look up case study flag
extrapolate <- extrapolate[btop]

# Key
setkey(extrapolate, fips, definition, adjustment, match.type)

# Order
setcolorder(extrapolate, c(key(extrapolate), 
                           c("case", "effect", "adoption_rate")))



# Save ####
extrapolate.rda <- file.path(parent.dir, "Statistical Analysis", 
                             "Extrapolation Table.rda")
save(extrapolate, file = extrapolate.rda)



# Write ####
extrapolate.xlsx <- file.path(parent.dir, "Statistical Analysis", 
                              "Extrapolation Table.xlsx")
write.xlsx2(extrapolate, extrapolate.xlsx, row.names = FALSE)
